*****************************************************************************;
**This is ~/sic/exportchanges_annual.sas                                   **;
**The input files are ~/sic/rawdata/SIC_2digit/SIC_2DIGIT_MONTH_97.txt and **;
**  SIC_2DIGIT_MONTH_98.TXT.                                               **;
**The data libraries used are ~/sic/rawdata/xprice.ssd01 and x_out_96.ssd01**;
**This program creates the "real" changes in export levels that are        **;
**  in Table 5 (Year/YTD column).  It also creates the year/ytd export     **;
**  effect on gross output shown in Table 7 of the Pollard/Coughlin        **;
**  Review article.                                                        **;
**When new data becomes available change %let goyr= to account for new     **;
**  gross output data and %let yr?= to account for new export level data.  **;
*****************************************************************************;

filename in '/users2/h1hlb00/sic/rawdata/SIC_2digit';
filename in2 '/users2/h1hlb00/sic/rawdata';
libname out '/users2/h1hlb00/sic/rawdata';

%let yr1  = 97;
%let yr2  = 98;
%let goyr = 96;

**************************************************;
**PULL IN YEAR TO DATE EXPORT LEVELS FROM ITC   **;
**REMEMBER TO CHANGE "Hong Kong" TO "Hong_Kong" **;
**When there is not a complete year of data     **;
**  you will have to change the input line to   **;
**  account for the available data              **;
**************************************************;
data datain&yr2(keep=country siccode x_y&yr2);
  infile in(SIC_2DIGIT_MONTH_&yr2..TXT) firstobs=3 dlm=",";
  input country $ siccode x_m1-x_m12;
  x_y&yr2=sum(of x_m1-x_m12);
run;
proc sort data=datain&yr2; 
  by country siccode; 
run;

**************************************************;
**PULL IN YEAR TO DATE EXPORT LEVELS FROM ITC   **;
**REMEMBER TO CHANGE "Hong Kong" TO "Hong_Kong" **;
**************************************************;
data datain&yr1(keep=country siccode x_y&yr1);
  infile in(SIC_2DIGIT_MONTH_&yr1..TXT) firstobs=3 dlm=",";
  input country $ siccode x_m1-x_m12;
  x_y&yr1=sum(of x_m1-x_m12);
run;
proc sort data=datain&yr1; 
  by country siccode; 
run;

data datain;
  merge datain&yr1 datain&yr2;
  by country siccode;
run;
proc sort data=datain; 
  by country; 
run;

***************************;
**COMBINE SIC01 and SIC02**;
***************************;
proc means data=datain(where=(siccode in(1,2))) sum noprint;
  var x_y&yr1 x_y&yr2;
  by country;
  output out=_12 sum=;
run;

*******************************;
**COMBINE SIC07, SIC08, SIC09**;
*******************************;
proc means data=datain(where=(siccode in(7,8,9))) sum noprint;
  var x_y&yr1 x_y&yr2;
  by country;
  output out=_79 sum=;
run;

****************************************;
**GIVE COMBO SIC CODE FOR ABOVE GROUPS**;
****************************************;
data datain;
  set datain
      _12(in=sic0102)
      _79(in=sic0709);
  if sic0102=1 then siccode=102;
  if sic0709=1 then siccode=709;
run;

**************************************************************;
**CREATE NOMINAL CHANGE IN X LEVELS FOR INDIVIDUAL COUNTRIES**;
**************************************************************;
proc sort data=datain; 
  by siccode; 
run;
data xlevels; 
  set datain;
  if 100>siccode>39 or siccode="." then delete;
  nom_chg = ((x_y&yr2/x_y&yr1)-1)*100;
run;

proc sort data=xlevels; 
  by siccode country; 
run;
***********************************************************;
**CREATE REAL CHANGE IN X LEVELS FOR INDIVIDUAL COUNTRIES**;
**  Use deflated export price indices to create real.    **;
***********************************************************;
data deflate;
  merge xlevels(drop=nom_chg) out.xprice(where=(siccode<>0));
  by siccode;
  real_y&yr2 = (x_y&yr2/(y&yr2/100));  
  real_y&yr1 = (x_y&yr1/(y&yr1/100));
  real_chg = ((real_y&yr2/real_y&yr1)-1)*100;
  if 100>siccode>39 or siccode="." then delete;
run;

**************************************************;
**PRINT REAL EXPORT LEVELS BY COUNTRY FROM USITC**;
**************************************************;
proc print data=deflate noobs;
  var siccode country x_y&yr2 y&yr2 real_y&yr2 x_y&yr1 y&yr1 real_y&yr1;
  title "Real Export Levels";
  title2 "By Country, From 19&yr1 to 19&yr2";
run;

*******************************************************;
**PREPARE TO GROUP COUNTRIES USING REAL EXPORT LEVELS**;
*******************************************************;
proc sort data=deflate; 
  by siccode; 
run;
proc transpose data=deflate out=real_c;
  by siccode;
  var real_chg;
  id country;
run;

**************************************************;
**PRINT REAL EXPORT CHANGE BY COUNTRY FROM USITC**;
**************************************************;
proc print;
  title "Real Percent Changes-Year to date";
  title2 "By Country, From 19&yr1 to 19&yr2";
run;

********************************************;
**GROUP COUNTRIES USING REAL EXPORT LEVELS**;
********************************************;
**Country group 4  (Asian 10) -- Indonesia, Malaysia, Philippines, Korea, Thailand, Hong_Kong  Singapore, Taiwan, China, Japan;
   proc means data=deflate
      (where=(country in ("Indonesi","Malaysia","Philippi","Korea","Thailand","Hong_Kon",
                          "Singapor","Taiwan","China","Japan")))   sum noprint;
     var real_y&yr2 real_y&yr1;
     class siccode;
     output out=group4 sum=rel_g4&yr2 rel_g4&yr1;
     title "Group 4";
   run;

********************************************;
**CREATE REAL CHANGE IN X LEVELS FOR A-10 **;
********************************************;
data groupchg(keep=siccode group4);
  set group4;
  group4 = ((rel_g4&yr2/rel_g4&yr1)-1)*100;
run;

*******************************************************;
**GET RID OF INDIVIDUAL SIC01,02,08,09 AND COMBO 1112**;
*******************************************************;
data real(drop=_name_);
  merge real_c groupchg;
  by siccode;
  if siccode in (1,2,8,9,1112) or siccode="." then delete;
run;

proc sort data=real; by group4; run;
**************************************************;
**PRINT REAL EXPORT CHANGE BY GROUP FROM USITC  **;
**************************************************;
proc print data=real noobs;
  var siccode group4;
  title "Real Percent Changes-Year to date";
  title2 "Asian 10, From 19&yr1 to 19&yr2";
run;

******************************************;
**CREATE YEAR TO DATE COLUMN FOR TABLE 5**;
**  Group 4 only                        **;
******************************************;
proc print data=real noobs;
  var siccode group4;
  title "Table 5 - ytd";
  title2 "U.S. Real Exports to East Asia by Industry";
  title3 "(percent change from year ago &yr1 to &yr2)";
  footnote "Sources:  U.S. Department of Commerce, Bureau of the Census.  U.S. Department of Labor,";
  footnote2 "Bureau of Labor Statistics.";
run;

****************************************************;
**CONVERT CHARACTER TO NUMERIC SIC FOR MERGE BELOW**;
****************************************************;
data x_out_&goyr;
  set out.x_out_&goyr;
  siccode=1*sic;
run;
proc sort data=x_out_&goyr; 
  by siccode; 
run;

******************************************;
**CREATE YEAR TO DATE VALUES FOR TABLE 7**;
**  Group 4 only                        **;
******************************************;
proc sort data=real; 
  by siccode; 
run;
data table7;
  merge real x_out_&goyr;
  by siccode;
t7group4=group4*ratio4;
run;

*****************************************;
**PRINT YEAR TO DATE COLUMN FOR TABLE 7**;
**  Group 4 only                       **;
*****************************************;
proc print data=table7 noobs;
  var siccode t7group4;
  title "Table 7 - ytd";
  title2 "Export Effect on Growth by Industry - Gross Output(&goyr) Basis";
  title3 "(percent &yr1 to &yr2)";
  footnote "Sources:  U.S. Department of Commerce, Bureau of the Census.  U.S. Department of Labor,";
  footnote2 "Bureau of Labor Statistics.";
run;

*******************************************************;
**PRINT MEAN OF YEAR TO DATE CHANGES SHOWN IN TABLE 7**;
*******************************************************;
proc means data=table7 noobs;
  var t7group4;
  title "Mean Export Effect on Growth - ytd";
  title2 "(percent &yr1 to &yr2)";
run;



