*****************************************************************************;
**This is ~/sic/sitc_deflatedpriceindex.sas                                **;
**The input files are ~/sic/rawdata/SITC_2digit/ForIndex/                  **;
**  x_priceindex_97to99.txt and SITC_2DIGIT_ANNUAL_95.TXT.                 **;
**This program creates SIC-based export price indices from raw SITC-based  **;
**  indices.  These price indices are used to deflate the raw export data  **;
**  to create the real percent changes reported in Table 5 of the Pollard/ **;
**  Coughlin Review article.                                               **;
**The 1995 nominal export levels are used to create weighted price indices **;
**  when you need to use a group of SITC indices to create the SIC index.  **;
**When creating a new year to date calculation, all you need to do is      **;
**  change the %let ytd= statement below to equal the number for the last  **;
**  month of available export level data.                                  **;
**This program was written by Heidi Beyer x8805                            **;
*****************************************************************************;
filename in '/users2/h1hlb00/sic/rawdata/SITC_2digit_ForIndex';
filename in2 '/users2/h1hlb00/sic/rawdata';
libname out '/users2/h1hlb00/sic/rawdata';

options pagesize=100 linesize=150 nocenter nodate;
*************************************;
**ENTER LAST MONTH FOR YEAR TO DATE**;
*************************************;
%let ytd = 12;

********************************************;
**PULL IN THE EXPORT PRICE LEVELS FROM BLS**;
********************************************;
data x_price(drop=nmq1_97 nmq2_97 nmq3_97 nmq4_97
                  nmq1_98 nmq2_98 nmq3_98 nmq4_98
                  nmq1_99 nmq2_99 nmq3_99 nmq4_99
                  _97m1-_97m12
                  _98m1-_98m12
                  ann97 ann98 ann99);
  infile in(x_priceindex_97to99.txt) linesize=1000 firstobs=305 dlm=","  pad;
  input seriesid $ _97m1-_97m12 ann97 $13.
                   _98m1-_98m12 ann98 $13.
                   _99m1   _99m2 $ _99m3 $ _99m4  $ _99m5  $ _99m6  $
                   _99m7 $ _99m8 $ _99m9 $ _99m10 $ _99m11 $ _99m12 $ ann99 $ @;
*******************************************************;
**CHANGE 1999 MISSING VALUES FROM ": No data" TO "." **;
*******************************************************;
    %macro strange;
      %do i = 1 %to 12;
         if substr(_99m&i,7,2)="No" then _99m&i=".";
      %end;
    %mend;
    %strange; 

  length sitccode 3.;
**********************************************************************;
**MAKE 2 DIGIT SITC CODES FOR THE 1-DIGIT MAJOR INDUSTRY GROUPINGS  **;
**********************************************************************;
    if compress(seriesid)="EIUIE1" then sitccode=1*10;
     else if compress(seriesid)="EIUIE2" then sitccode=2*10;
     else if compress(seriesid)="EIUIE3" then sitccode=3*10;
     else if compress(seriesid)="EIUIE4" then sitccode=4*10;
     else if compress(seriesid)="EIUIE5" then sitccode=5*10;
     else if compress(seriesid)="EIUIE6" then sitccode=6*10;
     else if compress(seriesid)="EIUIE7" then sitccode=7*10;
     else if compress(seriesid)="EIUIE8" then sitccode=8*10;
     else if compress(seriesid)="EIUIE9" then sitccode=9*10;
*******************************************************;
**MAKE SITC CODES FOR THE "OTHER" INDUSTRY GROUPINGS **;
*******************************************************;
     else if compress(seriesid)="EIUIE2R" then sitccode=222;
     else if compress(seriesid)="EIUIE8R" then sitccode=888;
****************************************************************;
**MAKE SITC CODE OUT OF THE LAST 2 DIGITS OF THE BLS MNEMONIC **;
****************************************************************;
     else sitccode = substr(seriesid,6,3);

**************************************************************;
**CREATE ANNUAL AND QUARTERLY AVERAGES FROM RAW MONTHLY DATA**;
**************************************************************;
    %macro chngfreq;
        %do i = 97 %to 99;
          **Create annual averages of available data;
            y&i=mean(of _&i.m1-_&i.m&ytd);
          **Create quarterly averages of available data;
            nmq1_&i=nmiss(of _&i.m1-_&i.m3);
            nmq2_&i=nmiss(of _&i.m4-_&i.m6);
            nmq3_&i=nmiss(of _&i.m7-_&i.m9);
            nmq4_&i=nmiss(of _&i.m10-_&i.m12);
            if nmq1_&i=0 then q1_&i=mean(of _&i.m1-_&i.m3);    else q1_&i=.;
            if nmq2_&i=0 then q2_&i=mean(of _&i.m4-_&i.m6);    else q2_&i=.;
            if nmq3_&i=0 then q3_&i=mean(of _&i.m7-_&i.m9);    else q3_&i=.;
            if nmq4_&i=0 then q4_&i=mean(of _&i.m10-_&i.m12);  else q4_&i=.;
        %end;
    %mend;
    %chngfreq;
run;

***************************************************;
**PRINT AVERAGE PRICE INDICES FOR VARIOUS PERIODS**;
***************************************************;
proc print;
  var sitccode q1_97 q1_98 q1_99 q2_97 q2_98 q2_99 q3_97 q3_98 q3_99 q4_97 q4_98 q4_99 y97 y98 y99;
  title "SITC Export Price Indices";
  title2 "(YTD Through Month=&ytd)";
run;

********************************************;
**PULL IN THE 1995 EXPORT LEVELS FROM ITC **;
**Use 1995 because the export prices have **;
**  a 1995 base period.                   **;
********************************************;
data x_levels(drop=sitccode);
  infile in(SITC_2DIGIT_ANNUAL_95.TXT) firstobs=3 dlm="," pad;
  input sitccode x95level;

  *Create groups for changing SITC into SIC where there is no direct match between them;
    if sitccode in(0,2,4,5,21,22) then group1=x95level;
    if sitccode in(1,2,3,4,5,6,7,8,9,11,29,41,42,43) then group2=x95level;
    if sitccode in(23,62) then group3=x95level;
    if sitccode in(24,63,81) then group4=x95level;
    if sitccode in(25,64) then group5=x95level;
    if sitccode in(26,65) then group6=x95level;
    if sitccode in(51,52,53,54,55,56,57,58,59) then group7=x95level;
    if sitccode in(61,83,85) then group8=x95level;
    if sitccode in(67,68) then group9=x95level;
    if sitccode in(71,72,73,74,75) then group10=x95level;
    if sitccode in(76,77) then group11=x95level;
    if sitccode in(78,79) then group12=x95level;
    if sitccode in(87,88) then group13=x95level;

  *Assign SITC codes to use for industries where there is no 2-digit SITC export price index;
    if sitccode in(0,2,6,7) then sitc_new=0;
       else if sitccode in(11) then sitc_new=10;
       else if sitccode in(23,29) then sitc_new=222;
       else if sitccode in(34) then sitc_new=30;
       else if sitccode in(41,42,43) then sitc_new=40;
       else if sitccode in(61) then sitc_new=60;
       else if sitccode in(79) then sitc_new=70;
       else if sitccode in(81,83,85) then sitc_new=888;
      else sitc_new=sitccode;
    sitc_old=sitccode;
run;

********************************************;
**CREATE EXPORT LEVELS FOR GROUPS WITH NO **;
**  SITC=SIC DIRECT MATCH                 **;
********************************************;
proc means data=x_levels sum;
  var group1-group13;
  output out=grplevel sum=;
  title "1995 Export Levels by Groups of SITCs";
run;

********************************************;
**COMBINE GROUP LEVELS AND INDIVID LEVELS **;
********************************************;
data x_levels;
  if _n_=1 then set grplevel;
  set x_levels(keep=sitc_old sitc_new x95level);
run;

******************************;
**PRINT 1995 EXPORT LEVELS  **;
******************************;
proc print;
  var sitc_old sitc_new x95level;
  title "Export Levels by SITC Codes";
  title2 "Annual 1995";
run;

********************************************;
**CREATE SHARE INDEX FOR EACH SITC IN GROUP*;
**SHARE = PRICEINDEX * 1995LEVEL/GROUPLEVEL*;
********************************************;
proc sort data=x_price; by sitccode; run;
proc sort data=x_levels; by sitc_new; run;
data start;
  merge x_price x_levels(rename=(sitc_new=sitccode));
  by sitccode;

  %macro defgrp(sitcno=,gno=,freq=);
    %do i = 1 %to 54  ;
    %let g=%scan(&gno,&i);
    %let s=%scan(&sitcno,&i);
      %do j=1 %to 15;
      %let f=%scan(&freq,&j);
        if sitc_old = &s then g&g&f=&f*x95level/group&g;
      %end;
    %end;
  %mend;
  %defgrp(sitcno=0 2 4 5 21 22 1 2 3 4 5 6 7 8 9 11 29 41 42 43 23 62 24 63 81 25 64 26 65 51 52 53
                 54 55 56 57 58 59 61 83 85 67 68 71 72 73 74 75 76 77 78 79 87 88,
          gno=1 1 1 1 1 1 2 2 2 2 2 2 2 2 2 2 2 2 2 2 3 3 4 4 4 5 5 6 6 7 7 7 7 7 7 7 7 7 8 8 8 9 9
              10 10 10 10 10 11 11 12 12 13 13,
          freq=y97 y98 y99 q1_97 q2_97 q3_97 q4_97 q1_98 q2_98 q3_98 q4_98 q1_99 q2_99 q3_99 q4_99);
run;

********************************************;
**SUM GROUP SHARES TO CREATE GROUP INDEX  **;
********************************************;
%macro grpindex;
  %do y = 97 %to 99;
    proc means data=start sum ;
      var g1y&y g2y&y g3y&y g4y&y g5y&y g6y&y g7y&y g8y&y g9y&y g10y&y g11y&y g12y&y g13y&y;
      output out=defy&y sum=;
      title "Export Deflated Export Price by Groups of SITCs 19&y";
    run;
  %do q = 1 %to 4;
    proc means data=start sum;
      var g1q&q._&y g2q&q._&y g3q&q._&y g4q&q._&y g5q&q._&y g6q&q._&y g7q&q._&y g8q&q._&y g9q&q._&y g10q&q._&y g11q&q._&y g12q&q._&y g13q&q._&y;
      output out=defq&q._&y sum=;
      title "Export Deflated Export Price Groups of SITCs 19&y Quarter &q";
    run;
  %end;
  %end;
%mend;
%grpindex;

********************************************;
**COMBINE GROUP DATA FROM ALL PERIODS     **;
********************************************;
data groups;
  merge defy97 defq1_97 defq2_97 defq3_97 defq4_97
        defy98 defq1_98 defq2_98 defq3_98 defq4_98
        defy99 defq1_99 defq2_99 defq3_99 defq4_99;
run;

***********************************************************;
**MATCH SIC TO SITC INDEXES WHERE THERE IS A DIRECT MATCH**;
***********************************************************;
data sic;
  input siccode sitccode;
  cards;
1      .
2      .
8      3
9      3
10     28
12     32
13     30
14     27
20     .
21     12
22     .
23     84
24     .
25     82
26     .
27     89
28     .
29     33
30     .
31     .
32     66
33     .
34     69
35     .
36     .
37     .
38     .
39     89
0102   .
0709   3
1112   32
;
proc sort data=sic; by sitccode; run;

*******************************;
**MATCH SITC DIRECTLY TO SIC **;
*******************************;
data sitc_sic;
  if _n_=1 then set groups;
  merge x_price (keep=sitccode y97 y98 y99 
  			           q1_97 q2_97 q3_97 q4_97
                               q1_98 q2_98 q3_98 q4_98 
                               q1_99 q2_99 q3_99 q4_99)
        sic;
  by sitccode;
*******************************;
**MATCH SITC GROUPS TO SIC   **;
*******************************;
  %macro tosic(vari=);
    %do i = 1 %to 15;
    %let v = %scan(&vari,&i);
      if sitccode<>"." and siccode<>"." then &v=&v;
        else if siccode in(1,2,102) then &v=g1&v;
        else if siccode in(20) then &v=g2&v;
        else if siccode in(30) then &v=g3&v;
        else if siccode in(24) then &v=g4&v;
        else if siccode in(26) then &v=g5&v;
        else if siccode in(22) then &v=g6&v;
        else if siccode in(28) then &v=g7&v;
        else if siccode in(31) then &v=g8&v;
        else if siccode in(33) then &v=g9&v;
        else if siccode in(35) then &v=g10&v;
        else if siccode in(36) then &v=g11&v;
        else if siccode in(37) then &v=g12&v;
        else if siccode in(38) then &v=g13&v;
    %end;
  %mend;
  %tosic(vari=y97 y98 y99 q1_97 q2_97 q3_97 q4_97 q1_98 q2_98 q3_98 q4_98 q1_99 q2_99 q3_99 q4_99);
  if siccode="." or siccode=0 then delete;
run;

********************************************************;
**CREATE DATASET TO DEFLATE THE EXPORT LEVELS FROM ITC**;
**   Used to create Tables 5 and 7                    **;
********************************************************;
proc sort data=sitc_sic out=out.xprice; by siccode; run;
proc print;
  var siccode sitccode q1_97 q1_98 q2_97 q2_98 q2_99 q3_97 q3_98 q3_99 q4_97 q4_98 q4_99 y97 y98;
  title "SIC Export Price Indices";
  title2 "(YTD Through Month=&ytd)";
run;


